@@ -1,11 +1,17 @@
 #import ctypes
 #ctypes.windll.user32.SetProcessDPIAware()
+import math
 import os
 import random
 import sys
+from typing import Union
 
 import pygame.gfxdraw
+import pygame_gui
 import pygame_gui as pg_g
+from pygame_gui.core import UIElement, IContainerLikeInterface
+from pygame_gui.elements import UIWindow, UIImage, UIVerticalScrollBar
+
 os.environ['SDL_AUDIODRIVER'] = 'dsp'
 sys.path.insert(0, '../frontiersman')
 from frontiersman.gameboard.NodeRoads import *
@@ -15,7 +21,9 @@ from frontiersman.client import ClientHelper
 from frontiersman.client import Actions
 from frontiersman.client.CardPickerGui import CardPickerGui
 from frontiersman.client.TraderGui import TradeGui
-from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
+#from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
+
+#assuming 1920 x 1080 to be res_full = 100.00
 
 # todo move some of these to GuiConstants.py
 RESOLUTION = (1920, 1080)
@@ -24,6 +32,17 @@ ACTION_SIZE = (70, 98)
 SCALE = 5 / 16
 HEX_SIZE = 600 * SCALE
 WINDOW_CENTER = (RESOLUTION[0] / 2, RESOLUTION[1] / 2)
+
+#for prototype
+FULLSCREEN = False
+RESOLUTION = (960, 540)
+PROTOTYPE_SCALE = 50/100
+ACTION_SIZE = (int(70 * PROTOTYPE_SCALE), int(98 * PROTOTYPE_SCALE))
+HEX_SIZE = 600 * SCALE * PROTOTYPE_SCALE
+WINDOW_CENTER = (RESOLUTION[0] / 2, RESOLUTION[1] / 2)
+SPACING = 1
+CARD_SIZE = (35, 45)
+
 COLORS = {
     'red': (127, 0, 0),
     'cyan': (0, 255, 255),
@@ -64,6 +83,69 @@ PLAYER_HEIGHT = 150
 PLAYER_SECTION_WIDTH = (INFO_WIDTH - 4 * SPACING) / 5
 PLAYER_QUARTER_HEIGHT = (PLAYER_HEIGHT - 2 * SPACING) / 4
 
+#prototype
+'''
+BANK_SCALE = 1.0
+INFO_WIDTH = int(320 * BANK_SCALE)
+BANK_HEIGHT = int(100 * BANK_SCALE)
+BANK_CARD_WIDTH = int((INFO_WIDTH - 8 * SPACING - BANK_HEIGHT) / 6 * BANK_SCALE)
+BANK_HALF_HEIGHT = int((BANK_HEIGHT - 3 * SPACING) / 2 * BANK_SCALE)
+PLAYER_HEIGHT = int(150 * BANK_SCALE)
+PLAYER_SECTION_WIDTH = int((INFO_WIDTH - 4 * SPACING) / 5 * BANK_SCALE)
+PLAYER_QUARTER_HEIGHT = int((PLAYER_HEIGHT - 2 * SPACING) / 4 * BANK_SCALE)
+'''
+
+
+class help_image(UIVerticalScrollBar):
+    def __init__(self, ui_manager,
+                 container: Union[IContainerLikeInterface, None] = None,
+                 parent_element: UIElement = None,):
+        super().__init__(relative_rect=pygame.Rect((769 - 32 - 2, 0 - 2), (32 + 2, 346)),
+                         visible_percentage=.62,
+                         manager=ui_manager,
+                         container=container,
+                         parent_element=parent_element)
+        self.HELP_IMAGE = pygame.image.load('../assets/help.png')
+        self.size = self.HELP_IMAGE.get_size()
+        self.background = pygame.Surface(self.size)
+        self.background.fill((0, 0, 0))
+        self.visible_percentage = .5
+        self.manager = ui_manager
+        self.background = pygame.Surface(self.size)
+        self.background = self.background.convert()
+
+    def draw(self, surface):
+        surface.blit(self.background, (0, 0))
+        surface.blit(self.HELP_IMAGE, (0, 0 - int(self.scroll_position * 4)))
+
+
+class help_window(UIWindow):
+    def __init__(self, position, ui_manager):
+        self.size = (769 + 28, 400)
+        image_size = (737, 802)
+        super().__init__(pygame.Rect(position, self.size), ui_manager,
+                         window_display_title='Help Window',
+                         object_id='#help_window')
+
+        surface_size = self.get_container().get_size()
+        self.surface_element = UIImage(pygame.Rect((0, 0),
+                                                   surface_size),
+                                       pygame.Surface(surface_size).convert(),
+                                       manager=ui_manager,
+                                       container=self,
+                                       parent_element=self)
+
+        self.help_image = help_image(ui_manager, container=self, parent_element=self)
+
+        self.is_active = False
+
+        self.set_blocking(True)
+
+    def update(self, time_delta):
+        super().update(time_delta)
+
+        self.help_image.draw(self.surface_element.image)
+
 
 class Client:
     # for mapping hexagon tiles to x,y
@@ -158,7 +240,7 @@ class Client:
         self.hex_size = HEX_SIZE
         self.port_textures = PORT_TEXTURES
         self.texture_dictionary = TILE_TEXTURES
-        self.scale = SCALE
+        self.scale = SCALE * PROTOTYPE_SCALE
         self.card_images = CARD_IMAGES
         self.road_points = ROAD_POINTS
 
@@ -175,7 +257,7 @@ class Client:
             for i in range(0, self.building_locations.settleColLength):
                 if self.building_locations.settlements[i][j].available:
                     settlement_buttons.append(
-                        CircleButton((125, 125, 255), (255, 255, 255), (40, 40),
+                        CircleButton((125, 125, 255), (255, 255, 255), (int(40 * PROTOTYPE_SCALE), int(40 * PROTOTYPE_SCALE)),
                                      CornerNode.translate_settlement((i, j), self.board_center, int(self.hex_size / 2)),
                                      "center", self.board_setup_coordinates_display,
                                      [str(i), str(j)]))
@@ -187,7 +269,8 @@ class Client:
             if edge is not None:
                 if edge.real:
                     road_buttons.append(
-                        CircleButton((125, 125, 255), (255, 255, 255), (40, 40),
+                        CircleButton((125, 125, 255), (255, 255, 255),
+                                     (int(40 * PROTOTYPE_SCALE), int(40 * PROTOTYPE_SCALE)),
                                      EdgeNode.translate_road((edge.cord1, edge.cord2), self.board_center,
                                                              int(self.hex_size / 2)), "center",
                                      self.board_setup_coordinates_display,
@@ -802,7 +885,7 @@ class Client:
         self.board_updated = bool1
 
     def render_dice(self, rolls):
-        size = 80
+        size = int(80 * PROTOTYPE_SCALE)
         width = len(rolls) * (2 * SPACING + size) - 2 * SPACING
         height = size
 
@@ -855,21 +938,31 @@ class Client:
         pygame.init()
         pygame.display.set_caption('Client')
         os.chdir(os.path.dirname(__file__))
-        font_size = 45
+        font_size = int(45 * PROTOTYPE_SCALE)
         self.font = pygame.font.SysFont('Comic Sans MS', font_size)
-        screenstring="localhost:"+self.player.screen_num
-        os.environ["DISPLAY"]=screenstring
+
+        font_size = int(45 * PROTOTYPE_SCALE)
+        self.font_bank = pygame.font.SysFont('Comic Sans MS', font_size)
+
+        screenstring = "localhost:0."+self.player.screen_num
+        os.environ["DISPLAY"] = screenstring
         os.environ['SDL_VIDEODRIVER'] = 'x11'
-        self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
+        if FULLSCREEN:
+            self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
+        else:
+            self.game_window = pygame.display.set_mode(RESOLUTION)
+
         cursor = pygame.cursors.arrow
         pygame.mouse.set_cursor(*cursor)
-        # self.game_window = pygame.display.set_mode(RESOLUTION)
+
         self.manager = pg_g.UIManager(RESOLUTION, '../themes/card_theme.json')
         self.clock = pygame.time.Clock()
 
         # creates settlement polygon
         house_width = 120 * self.scale / 2
         house_height = -135 * self.scale / 2
+        self.house_width = 120 * self.scale / 2
+        self.house_height = -135 * self.scale / 2
         self.house_points = [
             [-house_width, -house_height],
             [-house_width, 0],
@@ -881,6 +974,9 @@ class Client:
         # creates city polygon
         city_width = 120 * self.scale / 2
         city_height = -120 * self.scale / 2
+
+        self.city_width = 120 * self.scale / 2
+        self.city_height = -120 * self.scale / 2
         difference = -5
 
         self.city_points = [
@@ -900,6 +996,9 @@ class Client:
 
         self.board_center = (
             RESOLUTION[0] / 2 - int(self.hex_size / 2), RESOLUTION[1] / 2 - int(self.hex_size / 2) - CARD_SIZE[1] / 2)
+        #prototype
+        self.board_center = (
+            RESOLUTION[0] / 2 - int(self.hex_size / 2) - 150, RESOLUTION[1] / 2 - int(self.hex_size / 2) - CARD_SIZE[1] / 2)
 
         self.resource_hexes = self.game_board.land_list
         self.port_hexes = self.game_board.port_list
@@ -1197,15 +1296,15 @@ class Client:
                 self.card_trader.handle_ui_button_pressed(event)
             if event.ui_element == self.help_button:
                 if self.help_window is None:
-                    self.help_window = pg_g.elements.UIImage(
-                        relative_rect=pygame.Rect(75, 75, 737, 802),
-                        image_surface=pygame.image.load("assets/help.png"),
-                        manager=self.manager,
-                    )
-
+                    self.help_window = help_window((10, 10), self.manager)
                 else:
-                    self.help_window.kill()
-                    self.help_window = None
+                    if not self.help_window.alive():
+                        self.help_window.kill()
+                        self.help_window = None
+                        self.help_window = help_window((10, 10), self.manager)
+                    else:
+                        self.help_window.kill()
+                        self.help_window = None
             elif event.ui_element == self.trade_button:
                 if self.card_trader is None:
                     def callback(trade_with, give_cards, take_cards):
@@ -1324,7 +1423,7 @@ class Client:
         # draw Board
         self.game_window.blit(self.object_textures.get('Board'),
                               (int(self.board_center[0] - self.grid_size[0] / 2 + self.hex_size / 2),
-                               int(self.board_center[1] - self.grid_size[1] / 2 + self.hex_size / 2)))
+                               int(self.board_center[1] - self.grid_size[1] / 2 + self.hex_size / 2) - 1))
         # draw resource numbers
         for tile in self.resource_hexes:
             if tile.resource == 'Desert':
@@ -1349,19 +1448,21 @@ class Client:
                                                        int(self.hex_size / 2))
             if properties.city:
                 for points in self.city_points:
-                    shifted_points.append((location[0] + points[0], location[1] + points[1]))
+                    shifted_points.append((location[0] + points[0] - self.city_width / 2,
+                                           location[1] + points[1] + self.city_height))
 
                 pygame.gfxdraw.filled_polygon(self.game_window, shifted_points, COLORS[properties.color])
             else:
                 for points in self.house_points:
-                    shifted_points.append((location[0] + points[0], location[1] + points[1]))
+                    shifted_points.append((location[0] + points[0] - self.house_width / 2,
+                                           location[1] + points[1] + self.house_height))
 
                 pygame.gfxdraw.filled_polygon(self.game_window, shifted_points, COLORS[properties.color])
 
         # draw roads
         for properties in self.road_list:
             location = EdgeNode.translate_road((properties.cord1, properties.cord2), self.board_center,
-                                               int(self.hex_size / 2))
+                                               self.hex_size / 2)
             shifted_points = []
             # variation 0, 1, 2 = |, /, \
 
@@ -1372,13 +1473,28 @@ class Client:
             else:
                 variation = 2
 
+            self.road_length = self.hex_size / 4
+            self.road_width = self.road_length / 15
+
+            x_off = self.road_length * math.sin(math.pi / 6)
+            y_off = self.road_length * math.cos(math.pi / 6)
+            ratio = math.sin(math.pi / 3)
+
+            offset = [
+                [-self.road_width * 4, -self.road_width * 4],
+                [-12 * PROTOTYPE_SCALE, -14 * PROTOTYPE_SCALE],
+                [-12 * PROTOTYPE_SCALE, -14 * PROTOTYPE_SCALE]
+            ]
+
             for points in self.road_points[variation]:
-                shifted_points.append((location[0] + points[0], location[1] + points[1]))
+                shifted_points.append((location[0] + points[0] + offset[variation][0],
+                                       location[1] + points[1] + offset[variation][1]))
 
             pygame.gfxdraw.filled_polygon(self.game_window, shifted_points, COLORS[properties.color])
+
         loc = self.translate_hex_to_xy(self.game_board.get_robber().location, self.board_center, int(self.hex_size / 2))
         pygame.draw.circle(self.game_window, (50, 50, 50),
-                           (loc[0] + int(self.hex_size / 3), loc[1] + int(self.hex_size / 3)), 30)
+                           (loc[0] + int(self.hex_size / 3), loc[1] + int(self.hex_size / 3)), int(30 * PROTOTYPE_SCALE))
 
         if self.board_action == "initialsettlement" or self.board_action == "set" or self.board_action == "city":
             for butt in self.set_butts:
